package add_media_cluster;

# Author : Daniel Viard <dviard@mandrakesoft.com>
# Version 0.1
# please report bug to: cooker@mandrakesoft.com

use strict;
use Term::ANSIColor;
use MDK::Common;
use cluster_clientconf;
use cluster_commonconf;
use cluster_fonction_common;
use Getopt::Std;

# test root capa
AmIRoot();

sub usage {
  die "usage: $0 [-h] -p Protocol
    -h          : this (help) message
    -p Protocol : protocol to add media [HTTP|FTP]

    EXAMPLE: $0 -p HTTP
    ";
}

sub check_protocol {
  my ($protocol) = @_;

  die "Error : Unknown '$protocol' protocol, choose HTTP or FTP." if !member($protocol, qw(http ftp));
}

sub print_info {
  my ($protocol) = @_;

  check_protocol($protocol);

  print "   !!  WARNING  !!\n";
  print "\n";
  print " - all previous urpmi database will be remove\n";
  print "   and a $protocol RPM database on server will be added\n";
  print "   (crtl+c to abort)\n";
  print "\n";
  print " 3...\n"; sleep 1; print " 2..\n"; sleep 1; print " 1.\n"; sleep 1;

}

sub remove_media {
  eval { sys('urpmi.removemedia -a') };
}

sub add_media {
  my ($protocol) = @_;

  check_protocol($protocol);

  my $server =  cluster_clientconf::catch_dhcp()->{NEXT_SERVER};

  if ($protocol eq 'ftp') {

    my $user_install = cluster_commonconf::install_data()->{USER_INSTALL_LOGIN};
    my $passwd = cluster_commonconf::install_data()->{USER_INSTALL_PASSWD};

    sys("wget ftp://$user_install:$passwd\@$server/Mandrake/base/hdlists >/dev/null");

    foreach my $line (cat_('hdlists')) {
      my ($hdlist, $rpmdir) = $line =~ /hdlist(\d+)\.cz\s+(\S+)\s+/;

      sys("urpmi.addmedia ftp$hdlist ftp://$user_install:$passwd\@$server/$rpmdir with ../base/hdlist$hdlist.cz");
    }

    eval { rm_rf('hdlists') };

  } else {

    sys("urpmi.addmedia base http://$server/install/Mandrake/RPMS with ../base/hdlist1.cz");

    # NO RPMSCOM in ia64 ARCH and in i586 if NB_MEDIA != 3
    if (cluster_commonconf::mysystem()->{ARCH} ne 'ia64' && cluster_commonconf::install_data()->{NB_MEDIA} ne '3') {
      sys("urpmi.addmedia com http://$server/install/Mandrake/RPMSCOM with ../base/hdlist2.cz");
    }

    sys("urpmi.addmedia cluster http://$server/install/Mandrake/RPMCLUSTER with ../base/hdlist3.cz");
  }

}

sub main {
  my %opt;
  getopts("p::h", \%opt) or usage();

  $opt{p} or usage();
  $opt{h} and usage();

  my $protocol = lc $opt{p};

  check_protocol($protocol);

  print_info($protocol);

  remove_media();

  add_media($protocol);

}

1;
